====================
``highlight`` module
====================

.. automodule:: whoosh.highlight

See :doc:`how to highlight terms in search results </highlight>`.

Fragmenters
===========

.. autoclass:: WholeFragmenter
.. autoclass:: SimpleFragmenter
.. autoclass:: SentenceFragmenter
.. autoclass:: ContextFragmenter


Scorers
=======

.. autoclass:: BasicFragmentScorer


Formatters
==========

.. autoclass:: UppercaseFormatter
.. autoclass:: HtmlFormatter
.. autoclass:: GenshiFormatter


Utility classes
===============

.. autoclass:: Fragment
    :members:
